@@ -13,6 +13,7 @@
 from gi.repository import Gtk, GLib, Gio, Pango
 
 from gettext import gettext as _
+import re
 
 from lollypop.define import App, ArtSize, ViewType, MARGIN, MARGIN_SMALL, Type
 from lollypop.define import ARTISTS_PATH
@@ -139,21 +140,20 @@ class InformationView(View):
                                     ArtBehaviour.CACHE,
                                     self.__on_artist_artwork)
             albums_view = AlbumsListView([], [],
-                                         ViewType.SCROLLED | ViewType.ALBUM)
+                                         ViewType.SCROLLED)
             albums_view.set_size_request(300, -1)
             albums_view.show()
             albums_view.set_margin_start(5)
+            albums_view.add_widget(albums_view.box)
             widget.attach(albums_view, 2, 1, 1, 2)
             albums = []
             storage_type = get_default_storage_type()
-            for album_id in App().albums.get_ids([artist_id],
-                                                 [],
-                                                 storage_type):
+            for album_id in App().albums.get_ids([], [artist_id],
+                                                 storage_type, True):
                 albums.append(Album(album_id))
             if not albums:
                 albums = [App().player.current_track.album]
-            # Allows view to be shown without lag
-            GLib.idle_add(albums_view.populate, albums)
+            albums_view.populate(albums)
         content = self.__information_store.get_information(self.__artist_name,
                                                            ARTISTS_PATH)
         if content is None:
@@ -164,8 +164,8 @@ class InformationView(View):
                                        self.__on_artist_information,
                                        self.__artist_name)
         else:
-            self.__bio_label.set_markup(
-                GLib.markup_escape_text(content.decode("utf-8")))
+            App().task_helper.run(self.__to_markup, content,
+                                  callback=(self.__bio_label.set_markup,))
 
 #######################
 # PROTECTED           #
@@ -208,8 +208,8 @@ class InformationView(View):
             @param event as Gdk.Event
         """
         if get_network_available("WIKIPEDIA"):
-            from lollypop.wikipedia import Wikipedia
-            wikipedia = Wikipedia()
+            from lollypop.helper_web_wikipedia import WikipediaHelper
+            wikipedia = WikipediaHelper()
             self.__stack.set_visible_child_name("select")
             App().task_helper.run(wikipedia.get_search_list,
                                   self.__artist_name,
@@ -222,8 +222,8 @@ class InformationView(View):
             @param row as Gtk.ListBoxRow
         """
         self.__stack.set_visible_child_name("main")
-        from lollypop.wikipedia import Wikipedia
-        wikipedia = Wikipedia()
+        from lollypop.helper_web_wikipedia import WikipediaHelper
+        wikipedia = WikipediaHelper()
         App().task_helper.run(wikipedia.get_content_for_page_id,
                               row.page_id, row.locale,
                               callback=(self.__on_wikipedia_get_content,))
@@ -231,6 +231,24 @@ class InformationView(View):
 #######################
 # PRIVATE             #
 #######################
+    def __to_markup(self, data):
+        """
+            Transform message to markup
+            @param data as bytes
+            @return str
+        """
+        pango = ["large", "x-large", "xx-large"]
+        start = ["^===*", "^==", "^="]
+        end = ["===*$", "==$", "=$"]
+        i = 0
+        text = GLib.markup_escape_text(data.decode("utf-8"))
+        while i < len(pango):
+            text = re.sub(start[i], "<b><span size='%s'>" % pango[i],
+                          text, flags=re.M)
+            text = re.sub(end[i], "</span></b>", text, flags=re.M)
+            i += 1
+        return text
+
     def __on_wikipedia_search_list(self, items):
         """
             Populate view with items
@@ -247,7 +265,8 @@ class InformationView(View):
             @param content as str
         """
         if content is not None:
-            self.__bio_label.set_text(content.decode("utf-8"))
+            App().task_helper.run(self.__to_markup, content,
+                                  callback=(self.__bio_label.set_markup,))
             self.__information_store.save_information(
                 self.__artist_name, ARTISTS_PATH, content)
 
@@ -274,8 +293,8 @@ class InformationView(View):
             self.__bio_label.set_text(
                 _("No information for %s") % self.__artist_name)
         else:
-            self.__bio_label.set_markup(
-                GLib.markup_escape_text(content.decode("utf-8")))
+            App().task_helper.run(self.__to_markup, content,
+                                  callback=(self.__bio_label.set_markup,))
             self.__information_store.save_information(self.__artist_name,
                                                       ARTISTS_PATH,
                                                       content)
